import { literal, number, object, optional, parse, string, union } from "valibot";
import { useScript } from "#imports";
const IntercomOptions = object({
  app_id: string(),
  api_base: optional(union([literal("https://api-iam.intercom.io"), literal("https://api-iam.eu.intercom.io"), literal("https://api-iam.au.intercom.io")])),
  name: optional(string()),
  email: optional(string()),
  user_id: optional(string()),
  // customizing the messenger
  alignment: optional(union([literal("left"), literal("right")])),
  horizontal_padding: optional(number()),
  vertical_padding: optional(number())
});
export function useScriptIntercom(options, _scriptOptions) {
  const scriptOptions = _scriptOptions || {};
  scriptOptions.beforeInit = () => {
    if (import.meta.dev)
      parse(IntercomOptions, options);
    if (import.meta.client)
      window.intercomSettings = options;
  };
  return useScript({
    key: "intercom",
    src: `https://widget.intercom.io/widget/${options?.app_id}`,
    defer: true
  }, {
    trigger: "onNuxtReady",
    ...scriptOptions,
    assetStrategy: "bundle",
    use() {
      return { Intercom: window.Intercom };
    }
  });
}
